import { Optional, Component, ChangeDetectionStrategy, Injectable, NgModule } from '@angular/core';
import { MatDialogRef, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { FormBuilder, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { WebAuth } from 'auth0-js';
import { Observable, Subject } from 'rxjs';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { MatButtonModule } from '@angular/material/button';
import { MatInputModule } from '@angular/material/input';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ConfigService {
    /**
     * @param {?} config
     */
    constructor(config) { }
}
/** @nocollapse */
ConfigService.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DialogComponent {
    /**
     * @param {?} dialogRef
     * @param {?} formBuilder
     */
    constructor(dialogRef, formBuilder) {
        this.dialogRef = dialogRef;
        this.formBuilder = formBuilder;
        let /** @type {?} */ formBuilderObj = {
            username: [null, [Validators.required, Validators.email, Validators.minLength(5)]],
            password: [null, [Validators.required, Validators.minLength(4)]]
        };
        this.loginForm = this.formBuilder.group(formBuilderObj);
    }
    /**
     * @param {?} formObj
     * @return {?}
     */
    post(formObj) {
        this.dialogRef.close(formObj);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.dialogRef.componentInstance.hasOwnProperty('err') === true) {
            this.error = this.dialogRef.componentInstance['err'];
        }
    }
}
DialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-dialog',
                template: `<form [formGroup]="loginForm" (ngSubmit)="post(loginForm.getRawValue())">
<h1 mat-dialog-title>Authentication</h1>
<mat-dialog-content>
    <mat-form-field>
        <input matInput formControlName="username" placeholder="E-mail" required>
    </mat-form-field>
    <mat-form-field>
        <input matInput formControlName="password" placeholder="Password" type="password" required>
    </mat-form-field>
    <p *ngIf="error?.description">{{error.description}}</p>
    <p *ngIf="error?.error?.message?.error_description">{{error.error.message.error_description}}</p>
</mat-dialog-content>
<mat-dialog-actions>
    <button type="button" class="change-password" (click)="dialogRef.close('change-password')">Forgot password?</button>
    <button mat-button color="secondary" (click)="dialogRef.close()" type="button">Cancel</button>
    <button mat-raised-button color="primary" [disabled]="loginForm.pristine || loginForm.status === 'INVALID'" type="submit">Login</button>
</mat-dialog-actions>
</form>
`,
                styles: [`a,h1,p{font-family:Roboto,"Helvetica Neue",sans-serif}p{margin:0 0 10px;padding:0;color:red;font-size:12px}button.change-password{line-height:36px;display:inline-block;font-size:14px;border:none;background:0 0;margin:0!important;padding:0}button{margin-left:auto}input[type=password]{border:none!important;-webkit-box-shadow:none!important;box-shadow:none!important}`],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
DialogComponent.ctorParameters = () => [
    { type: MatDialogRef, },
    { type: FormBuilder, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class PasswordDialogComponent {
    /**
     * @param {?} dialogRef
     * @param {?} formBuilder
     */
    constructor(dialogRef, formBuilder) {
        this.dialogRef = dialogRef;
        this.formBuilder = formBuilder;
        let /** @type {?} */ formBuilderObj = {
            email: [null, [Validators.required, Validators.email, Validators.minLength(5)]]
        };
        this.passwordForm = this.formBuilder.group(formBuilderObj);
    }
    /**
     * @param {?} formObj
     * @return {?}
     */
    post(formObj) {
        this.dialogRef.close(formObj);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.dialogRef.componentInstance.hasOwnProperty('err') === true) {
            this.error = this.dialogRef.componentInstance['err'];
        }
    }
}
PasswordDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-password-dialog',
                template: `<form [formGroup]="passwordForm" (ngSubmit)="post(passwordForm.getRawValue())">
  <h1 mat-dialog-title>Forgot password</h1>
  <mat-dialog-content>
    <mat-form-field>
      <input matInput formControlName="email" placeholder="E-mail" required>
    </mat-form-field>
    <p *ngIf="error?.description">{{error.description}}</p>
  </mat-dialog-content>
  <mat-dialog-actions>
    <button mat-button color="secondary" (click)="dialogRef.close()" type="button">Cancel</button>
    <button mat-raised-button color="primary" [disabled]="passwordForm.pristine || passwordForm.status === 'INVALID'" type="submit">Change password</button>
  </mat-dialog-actions>
</form>
`,
                styles: [`a,h1,p{font-family:Roboto,"Helvetica Neue",sans-serif}p{margin:0 0 10px;padding:0;color:red;font-size:12px}button{margin-left:auto}input[type=password]{border:none!important;-webkit-box-shadow:none!important;box-shadow:none!important}mat-form-field{width:100%}`],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
PasswordDialogComponent.ctorParameters = () => [
    { type: MatDialogRef, },
    { type: FormBuilder, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MessageDialogComponent {
    /**
     * @param {?} dialogRef
     */
    constructor(dialogRef) {
        this.dialogRef = dialogRef;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
MessageDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-message-dialog',
                template: `<p>
  {{dialogRef?.componentInstance}}
</p>
`,
                styles: [`a,h1,p{font-family:Roboto,"Helvetica Neue",sans-serif}`]
            },] },
];
/** @nocollapse */
MessageDialogComponent.ctorParameters = () => [
    { type: MatDialogRef, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Auth0Service {
    /**
     * @param {?} config
     * @param {?} dialog
     * @param {?} http
     */
    constructor(config, dialog, http) {
        this.config = config;
        this.dialog = dialog;
        this.http = http;
        let /** @type {?} */ configObj = Object.assign({}, this.config['WebAuthConfig']); // hack to prevent type issue, i'm not sure how to really fix this
        if (configObj.hasOwnProperty('redirectUri') === false || configObj.redirectUri === null) {
            configObj.redirectUri = location.href;
        }
        this.auth0 = new WebAuth(configObj);
    }
    /**
     * @param {?} config
     * @return {?}
     */
    loginWithCredentials(config) {
        if (this.config.proxyUrl != null) {
            return this.http.post(`${this.config.proxyUrl}/sign-in`, { credentials: config });
        }
        else {
            return new Observable(observer => {
                this.auth0.popup.loginWithCredentials(config, (err, result) => {
                    if (err) {
                        console.log(err);
                        //this.loginByDialog(err);
                        observer.error(err);
                    }
                    else {
                        observer.next(result);
                    }
                });
            });
        }
    }
    /**
     * @param {?} config
     * @return {?}
     */
    login(config) {
        config.realm = config.connection;
        return new Observable(observer => {
            this.auth0.client.login(config, (err, result) => {
                if (err) {
                    console.log(err);
                }
                else {
                    observer.next(result);
                }
            });
        });
    }
    /**
     * @param {?} config
     * @return {?}
     */
    logout(config) {
        this.auth0.client.buildLogoutUrl(config);
    }
    /**
     * @return {?}
     */
    changePassword() {
        let /** @type {?} */ dialogRef = this.dialog.open(PasswordDialogComponent, { disableClose: true });
        dialogRef.afterClosed().subscribe(result => {
            if (result != null) {
                this.auth0.changePassword({
                    connection: 'Username-Password-Authentication',
                    email: result.email
                }, ((err, resp) => {
                    let /** @type {?} */ dialogRef = this.dialog.open(MessageDialogComponent, { disableClose: true });
                    dialogRef.componentInstance = err ? err.message : resp;
                }));
            }
        });
    }
    /**
     * @param {?=} err
     * @return {?}
     */
    loginByDialog(err = null) {
        let /** @type {?} */ that = this;
        let /** @type {?} */ observer = new Subject();
        let /** @type {?} */ dialogRef = that.dialog.open(DialogComponent, { disableClose: true });
        if (err != null) {
            dialogRef.componentInstance.err = err;
        }
        dialogRef.afterClosed().subscribe(result => {
            if (result != null && result !== 'change-password') {
                result.connection = that.config['connection'];
                that.loginWithCredentials(result).subscribe(res => {
                    observer.next(res);
                }, err => {
                    observer.error(err);
                });
            }
            else if (result != null && result === 'change-password') {
                this.changePassword();
                observer.error('Canceled login to change password');
            }
            else {
                observer.error('Canceled login');
            }
        });
        return observer;
    }
}
Auth0Service.decorators = [
    { type: Injectable },
];
/** @nocollapse */
Auth0Service.ctorParameters = () => [
    { type: ConfigService, },
    { type: MatDialog, },
    { type: HttpClient, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AppComponent {
    /**
     * @param {?} auth0Service
     */
    constructor(auth0Service) {
        this.auth0Service = auth0Service;
        this.title = 'app works!';
        this.selectedOption = 'string';
        this.loginByDialog();
    }
    /**
     * @param {?=} err
     * @return {?}
     */
    loginByDialog(err = null) {
        this.auth0Service.loginByDialog(err).subscribe(x => {
            console.log('logged in:', x);
        }, err => {
            console.log('error logging in:', err);
            //this.auth0Service.loginByDialog(err);
        });
    }
}
AppComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-root',
                template: ``,
                styles: [``]
            },] },
];
/** @nocollapse */
AppComponent.ctorParameters = () => [
    { type: Auth0Service, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const ɵ0 = {
    WebAuthConfig: {
        domain: 'sitespirit.eu.auth0.com',
        clientID: 'tqNF2in8RSQkYIFuvjTxGXLZTA1dMEzT',
        scope: 'openid profile email',
        responseType: 'token',
        redirectUri: location.href
    },
    connection: 'Username-Password-Authentication'
};
class Auth0Module {
    /**
     * @param {?} config
     * @return {?}
     */
    static forRoot(config) {
        return {
            ngModule: Auth0Module,
            providers: [
                {
                    provide: ConfigService,
                    useValue: config
                }
            ]
        };
    }
}
Auth0Module.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    AppComponent,
                    DialogComponent,
                    PasswordDialogComponent,
                    MessageDialogComponent
                ],
                entryComponents: [
                    DialogComponent,
                    PasswordDialogComponent,
                    MessageDialogComponent
                ],
                imports: [
                    BrowserModule,
                    BrowserAnimationsModule,
                    FormsModule,
                    ReactiveFormsModule,
                    HttpClientModule,
                    MatDialogModule,
                    MatButtonModule,
                    MatInputModule
                ],
                providers: [
                    Auth0Service,
                    { provide: ConfigService,
                        useValue: ɵ0
                    }
                ],
                bootstrap: [AppComponent]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { Auth0Module, Auth0Service, AppComponent as ɵa, DialogComponent as ɵd, MessageDialogComponent as ɵf, PasswordDialogComponent as ɵe, ConfigService as ɵb };
//# sourceMappingURL=ngx-auth0.js.map
