import { Optional, Component, ChangeDetectionStrategy, Injectable, NgModule } from '@angular/core';
import { MatDialogRef, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { FormBuilder, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { WebAuth } from 'auth0-js';
import { Observable, Subject } from 'rxjs';
import { HttpClient, HttpClientModule } from '@angular/common/http';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { MatButtonModule } from '@angular/material/button';
import { MatInputModule } from '@angular/material/input';

var ConfigService = /** @class */ (function () {
    function ConfigService(config) {
    }
    return ConfigService;
}());
ConfigService.ctorParameters = function () { return [
    { type: undefined, decorators: [{ type: Optional },] },
]; };
var DialogComponent = /** @class */ (function () {
    function DialogComponent(dialogRef, formBuilder) {
        this.dialogRef = dialogRef;
        this.formBuilder = formBuilder;
        var formBuilderObj = {
            username: [null, [Validators.required, Validators.email, Validators.minLength(5)]],
            password: [null, [Validators.required, Validators.minLength(4)]]
        };
        this.loginForm = this.formBuilder.group(formBuilderObj);
    }
    DialogComponent.prototype.post = function (formObj) {
        this.dialogRef.close(formObj);
    };
    DialogComponent.prototype.ngOnInit = function () {
        if (this.dialogRef.componentInstance.hasOwnProperty('err') === true) {
            this.error = this.dialogRef.componentInstance['err'];
        }
    };
    return DialogComponent;
}());
DialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-dialog',
                template: "<form [formGroup]=\"loginForm\" (ngSubmit)=\"post(loginForm.getRawValue())\">\n<h1 mat-dialog-title>Authentication</h1>\n<mat-dialog-content>\n    <mat-form-field>\n        <input matInput formControlName=\"username\" placeholder=\"E-mail\" required>\n    </mat-form-field>\n    <mat-form-field>\n        <input matInput formControlName=\"password\" placeholder=\"Password\" type=\"password\" required>\n    </mat-form-field>\n    <p *ngIf=\"error?.description\">{{error.description}}</p>\n    <p *ngIf=\"error?.error?.message?.error_description\">{{error.error.message.error_description}}</p>\n</mat-dialog-content>\n<mat-dialog-actions>\n    <button type=\"button\" class=\"change-password\" (click)=\"dialogRef.close('change-password')\">Forgot password?</button>\n    <button mat-button color=\"secondary\" (click)=\"dialogRef.close()\" type=\"button\">Cancel</button>\n    <button mat-raised-button color=\"primary\" [disabled]=\"loginForm.pristine || loginForm.status === 'INVALID'\" type=\"submit\">Login</button>\n</mat-dialog-actions>\n</form>\n",
                styles: ["a,h1,p{font-family:Roboto,\"Helvetica Neue\",sans-serif}p{margin:0 0 10px;padding:0;color:red;font-size:12px}button.change-password{line-height:36px;display:inline-block;font-size:14px;border:none;background:0 0;margin:0!important;padding:0}button{margin-left:auto}input[type=password]{border:none!important;-webkit-box-shadow:none!important;box-shadow:none!important}"],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
DialogComponent.ctorParameters = function () { return [
    { type: MatDialogRef, },
    { type: FormBuilder, },
]; };
var PasswordDialogComponent = /** @class */ (function () {
    function PasswordDialogComponent(dialogRef, formBuilder) {
        this.dialogRef = dialogRef;
        this.formBuilder = formBuilder;
        var formBuilderObj = {
            email: [null, [Validators.required, Validators.email, Validators.minLength(5)]]
        };
        this.passwordForm = this.formBuilder.group(formBuilderObj);
    }
    PasswordDialogComponent.prototype.post = function (formObj) {
        this.dialogRef.close(formObj);
    };
    PasswordDialogComponent.prototype.ngOnInit = function () {
        if (this.dialogRef.componentInstance.hasOwnProperty('err') === true) {
            this.error = this.dialogRef.componentInstance['err'];
        }
    };
    return PasswordDialogComponent;
}());
PasswordDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-password-dialog',
                template: "<form [formGroup]=\"passwordForm\" (ngSubmit)=\"post(passwordForm.getRawValue())\">\n  <h1 mat-dialog-title>Forgot password</h1>\n  <mat-dialog-content>\n    <mat-form-field>\n      <input matInput formControlName=\"email\" placeholder=\"E-mail\" required>\n    </mat-form-field>\n    <p *ngIf=\"error?.description\">{{error.description}}</p>\n  </mat-dialog-content>\n  <mat-dialog-actions>\n    <button mat-button color=\"secondary\" (click)=\"dialogRef.close()\" type=\"button\">Cancel</button>\n    <button mat-raised-button color=\"primary\" [disabled]=\"passwordForm.pristine || passwordForm.status === 'INVALID'\" type=\"submit\">Change password</button>\n  </mat-dialog-actions>\n</form>\n",
                styles: ["a,h1,p{font-family:Roboto,\"Helvetica Neue\",sans-serif}p{margin:0 0 10px;padding:0;color:red;font-size:12px}button{margin-left:auto}input[type=password]{border:none!important;-webkit-box-shadow:none!important;box-shadow:none!important}mat-form-field{width:100%}"],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
PasswordDialogComponent.ctorParameters = function () { return [
    { type: MatDialogRef, },
    { type: FormBuilder, },
]; };
var MessageDialogComponent = /** @class */ (function () {
    function MessageDialogComponent(dialogRef) {
        this.dialogRef = dialogRef;
    }
    MessageDialogComponent.prototype.ngOnInit = function () {
    };
    return MessageDialogComponent;
}());
MessageDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-message-dialog',
                template: "<p>\n  {{dialogRef?.componentInstance}}\n</p>\n",
                styles: ["a,h1,p{font-family:Roboto,\"Helvetica Neue\",sans-serif}"]
            },] },
];
MessageDialogComponent.ctorParameters = function () { return [
    { type: MatDialogRef, },
]; };
var Auth0Service = /** @class */ (function () {
    function Auth0Service(config, dialog, http) {
        this.config = config;
        this.dialog = dialog;
        this.http = http;
        var configObj = Object.assign({}, this.config['WebAuthConfig']);
        if (configObj.hasOwnProperty('redirectUri') === false || configObj.redirectUri === null) {
            configObj.redirectUri = location.href;
        }
        this.auth0 = new WebAuth(configObj);
    }
    Auth0Service.prototype.loginWithCredentials = function (config) {
        var _this = this;
        if (this.config.proxyUrl != null) {
            return this.http.post(this.config.proxyUrl + "/sign-in", { credentials: config });
        }
        else {
            return new Observable(function (observer) {
                _this.auth0.popup.loginWithCredentials(config, function (err, result) {
                    if (err) {
                        console.log(err);
                        observer.error(err);
                    }
                    else {
                        observer.next(result);
                    }
                });
            });
        }
    };
    Auth0Service.prototype.login = function (config) {
        var _this = this;
        config.realm = config.connection;
        return new Observable(function (observer) {
            _this.auth0.client.login(config, function (err, result) {
                if (err) {
                    console.log(err);
                }
                else {
                    observer.next(result);
                }
            });
        });
    };
    Auth0Service.prototype.logout = function (config) {
        this.auth0.client.buildLogoutUrl(config);
    };
    Auth0Service.prototype.changePassword = function () {
        var _this = this;
        var dialogRef = this.dialog.open(PasswordDialogComponent, { disableClose: true });
        dialogRef.afterClosed().subscribe(function (result) {
            if (result != null) {
                _this.auth0.changePassword({
                    connection: 'Username-Password-Authentication',
                    email: result.email
                }, (function (err, resp) {
                    var dialogRef = _this.dialog.open(MessageDialogComponent, { disableClose: true });
                    dialogRef.componentInstance = err ? err.message : resp;
                }));
            }
        });
    };
    Auth0Service.prototype.loginByDialog = function (err) {
        var _this = this;
        if (err === void 0) { err = null; }
        var that = this;
        var observer = new Subject();
        var dialogRef = that.dialog.open(DialogComponent, { disableClose: true });
        if (err != null) {
            dialogRef.componentInstance.err = err;
        }
        dialogRef.afterClosed().subscribe(function (result) {
            if (result != null && result !== 'change-password') {
                result.connection = that.config['connection'];
                that.loginWithCredentials(result).subscribe(function (res) {
                    observer.next(res);
                }, function (err) {
                    observer.error(err);
                });
            }
            else if (result != null && result === 'change-password') {
                _this.changePassword();
                observer.error('Canceled login to change password');
            }
            else {
                observer.error('Canceled login');
            }
        });
        return observer;
    };
    return Auth0Service;
}());
Auth0Service.decorators = [
    { type: Injectable },
];
Auth0Service.ctorParameters = function () { return [
    { type: ConfigService, },
    { type: MatDialog, },
    { type: HttpClient, },
]; };
var AppComponent = /** @class */ (function () {
    function AppComponent(auth0Service) {
        this.auth0Service = auth0Service;
        this.title = 'app works!';
        this.selectedOption = 'string';
        this.loginByDialog();
    }
    AppComponent.prototype.loginByDialog = function (err) {
        if (err === void 0) { err = null; }
        this.auth0Service.loginByDialog(err).subscribe(function (x) {
            console.log('logged in:', x);
        }, function (err) {
            console.log('error logging in:', err);
        });
    };
    return AppComponent;
}());
AppComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-root',
                template: "",
                styles: [""]
            },] },
];
AppComponent.ctorParameters = function () { return [
    { type: Auth0Service, },
]; };
var ɵ0 = {
    WebAuthConfig: {
        domain: 'sitespirit.eu.auth0.com',
        clientID: 'tqNF2in8RSQkYIFuvjTxGXLZTA1dMEzT',
        scope: 'openid profile email',
        responseType: 'token',
        redirectUri: location.href
    },
    connection: 'Username-Password-Authentication'
};
var Auth0Module = /** @class */ (function () {
    function Auth0Module() {
    }
    Auth0Module.forRoot = function (config) {
        return {
            ngModule: Auth0Module,
            providers: [
                {
                    provide: ConfigService,
                    useValue: config
                }
            ]
        };
    };
    return Auth0Module;
}());
Auth0Module.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    AppComponent,
                    DialogComponent,
                    PasswordDialogComponent,
                    MessageDialogComponent
                ],
                entryComponents: [
                    DialogComponent,
                    PasswordDialogComponent,
                    MessageDialogComponent
                ],
                imports: [
                    BrowserModule,
                    BrowserAnimationsModule,
                    FormsModule,
                    ReactiveFormsModule,
                    HttpClientModule,
                    MatDialogModule,
                    MatButtonModule,
                    MatInputModule
                ],
                providers: [
                    Auth0Service,
                    { provide: ConfigService,
                        useValue: ɵ0
                    }
                ],
                bootstrap: [AppComponent]
            },] },
];

export { Auth0Module, Auth0Service, AppComponent as ɵa, DialogComponent as ɵd, MessageDialogComponent as ɵf, PasswordDialogComponent as ɵe, ConfigService as ɵb };
//# sourceMappingURL=ngx-auth0.js.map
